import re
from datetime import datetime
from typing import Optional, Union, List

from pydantic import BaseModel, EmailStr, field_validator, ConfigDict, Field



class WalletBase(BaseModel):
    """Base schema for wallet"""

    id: str
    user_id: str
    balance: float
    created_at: datetime
    updated_at: datetime

    model_config = ConfigDict(from_attributes=True)


class WalletCreate(BaseModel):
    """Schema to create a wallet for a user"""

    user_id: str
    balance: float = Field(0.0, description="Initial wallet balance")


class WalletData(BaseModel):
    """Schema to return wallet data"""

    id: str
    user_id: str
    balance: float
    created_at: datetime
    updated_at: datetime

    model_config = ConfigDict(from_attributes=True)


class TokenBalanceData(BaseModel):
    """Schema to return token balance data"""

    id: str
    wallet_id: str
    token_id: str
    amount: float
    created_at: datetime
    updated_at: datetime

    model_config = ConfigDict(from_attributes=True)